API Reference
-------------

The API reference is a lexicographic list of all the different classes,
methods and features that Kivy offers.

.. toctree::
    :maxdepth: 2

    api-kivy.rst
    api-kivy.core.rst
    api-kivy.graphics.rst
    api-kivy.input.rst
    api-kivy.modules.rst
    api-kivy.uix.rst
